function [output] = getObsFixations(imgName)

%% SET UP:
%Folders:
warning off
HOME = pwd;
init(HOME)

%Initialize stuff:
exponentSAL = 0.025;                % modulates: SALIENCY MAP
exponentINRIA = 0.025;              % modulates: OBJECT MAP (INRIA)

dispMap = 1;

%% === WHICH FIXATIONS TO INCLUDE IN ANALYSIS === %%
LookWhichFixs = [1:3];
TestWithFixs = LookWhichFixs;

%Include Fixations on the Target Region? (1=Yes, 0=No)
IncludeTargetFixs = 1;

%% ====== OTHER SET UP STUFF ====== %%
%Figure stuff:
scnsize = get(0,'ScreenSize');
fullscn=[5 40  scnsize(3)-10 scnsize(4)-120];

%Eliminate trials with lost eyetracking (or wrong response):
criteria = {'badNaN';'badRT';'accuracy';};
setBadRT = 5000; %cut for badRT trials (ms)
badCriteria = {criteria{1} criteria{3}};

%Load Image:
if ~exist('imgName','var'); 
    load stimList
    stimList = stimList_ALL(randperm(length(stimList_ALL)))';
    imgName = [stimList{1} '.jpg'];
end
imgPath = which(imgName);
if isempty(imgPath);
    disp(['ERROR:  ' imgName '  was not found in the folder /eyeData ']); return;
else
    img = imread([imgName]);
    load(fullfile('Dataset_EyeData','eyeData',imgName(1:end-4)));
    eval(['stimFile = ' imgName(1:end-4) ';'])
end;

stimSize = size(img);  stimSize = stimSize(1:2);  %stimulus dimensions
whiteMat = zeros(stimSize);                   %blank matrix
LookWhichFixs = LookWhichFixs + 1;  %include offset for Initial Fixation

%% CHECK TRIAL VALIDITY (no lost eyetracking, Correct Response, Etc)...
Nsubs = size(stimFile.subdata,2); goodTrials = [];
for s = 1:Nsubs
    badNaN = double(stimFile.subdata(s).badNaN);
    badRT = double(stimFile.subdata(s).RT > setBadRT);
    accuracy = isempty(strmatch(stimFile.subdata(s).accuracy,'correct'));
    trial_Is_Ok = 1;
    for c=1:length(badCriteria); if eval(badCriteria{c}); trial_Is_Ok = 0; end;  end
    if IncludeTargetFixs
        hasFixs = find(stimFile.subdata(s).fixType~=0);  %(anything beside INITIAL fixation)
    else hasFixs = find(stimFile.subdata(s).fixType==1);  %(only SEARCH Fixs)
    end
    durCutoff = find(stimFile.subdata(s).fixDur >= 120);
    hasFixs = intersect(hasFixs,durCutoff);
    if isempty(hasFixs); trial_Is_Ok = 0; end
    if trial_Is_Ok; goodTrials = cat(2,goodTrials,s); end
end
Nsubs = length(goodTrials);

%% ============ GET RECORD OF OBSERVERS FIXATIONS FOR IMAGE ============ %%

recordOfFixs = [];
for s=goodTrials
    if IncludeTargetFixs
        hasFixs = find(stimFile.subdata(s).fixType~=0);  %(anything beside INITIAL fixation)
    else hasFixs = find(stimFile.subdata(s).fixType==1);  %(only SEARCH Fixs)
    end
    whichFixs = LookWhichFixs(find(ismember(LookWhichFixs,hasFixs)));
    nfixs = length(whichFixs);
    fixXY = cat(2,cat(2,repmat(s,nfixs,1),whichFixs'),round(stimFile.subdata(s).fixXY(whichFixs,:))); %[s Nfix X Y]
    if nfixs>0
        badX = find(fixXY(:,3)>800); fixXY(badX,3) = 800;
        badY= find(fixXY(:,4)>600);   fixXY(badY,4) = 600;
        recordOfFixs = cat(1,recordOfFixs,fixXY);
    end
    clear fixXY
end
Nfixs = size(recordOfFixs,1);

if Nfixs ~=0
    %Correct for fixation 0 offset when naming fixations in recordOfFixs
    recordOfFixs(:,2) = recordOfFixs(:,2) - 1;

    %% ============ FIND REGION DEFINED BY **ALL** OBSERVERS ============ %%
    imgFixReg_ALLobs = whiteMat;
    for f=1:Nfixs
        i = round(recordOfFixs(f,4)); j = round(recordOfFixs(f,3));
        clearMatrix = whiteMat;
        clearMatrix(i,j) = 1;
        blurEachFix = gaussian(clearMatrix, 8);
        imgFixReg_ALLobs = imgFixReg_ALLobs + blurEachFix;
    end

    %============ (Optional) Show Region & Fixs ============
    if dispMap
        figure('Position',fullscn);
        subplot(1,2,1); imagesc(img); title([ 'ORIGINAL STIMULUS: ' imgName]); axis off equal; hold on;
        subplot(1,2,2); imagesc(img); title(['Fixations used to define region']); axis off equal; hold on;
        subplot(1,2,2); plot(recordOfFixs(:,3),recordOfFixs(:,4),'o','MarkerSize',12,'LineWidth',2,'MarkerEdgeColor','y','MarkerFaceColor','r');   %REGION
        drawnow
    end

    %% ==== DETERMINE REGION DEFINED BY EACH SUBSET OF N-1 Os ==== %%xs
    % Image must have more than 1 observer with "goodTrial" criteria met (otherwise NULL values):
    output.imgName = stimFile.imgName;
    output.NcontribSs = Nsubs;
    output.DefineWithFixs = LookWhichFixs-1;
    output.TestWithFixs = TestWithFixs;
    output.recordOfFixs = [{'OsNo' 'FixNo' 'X' 'Y'}; num2cell(recordOfFixs)];
    if Nsubs > 1
        %Exclude one subject at a time (subject "N")
        N = 0;
        for NthSub = goodTrials
            N = N+1;

            %%%% Split up "recordOfFixs" into 'everyone except Nth' & 'Nth'
            includeObs = setdiff(goodTrials,NthSub);
            DefineRegionFixations = recordOfFixs(ismember(recordOfFixs(:,1),includeObs),:);
            TestRegionFixations = ...
                recordOfFixs(ismember(recordOfFixs(:,1),NthSub) & ismember(recordOfFixs(:,2),TestWithFixs),:);
            Nfixs_define = size(DefineRegionFixations,1);
            Nfixs_test = size(TestRegionFixations,1);

            %%%% Create imgFixRegions matrix for MAKE fixation predictions (sum ea. fixation, blur)
            imgFixRegions = whiteMat;
            for f=1:Nfixs_define
                i = round(DefineRegionFixations(f,4)); j = round(DefineRegionFixations(f,3));
                imgFixRegions(i,j) = imgFixRegions(i,j)+1;
            end
            imgFixRegions = gaussian(imgFixRegions, 8);

            %%%% Create agreeTextFix matrix for TESTING fixation predictions
            agreeTestFix = whiteMat;
            if Nfixs_test > 0
                for f=1:Nfixs_test
                    i = round(TestRegionFixations(f,4)); j = round(TestRegionFixations(f,3));
                    agreeTestFix(i,j) = 1;
                end
            end

            %% Get ROC curves for within-image human agreement
            [aROC, falseAlarmRate, detectionRate] = areaROC(imgFixRegions, agreeTestFix);
            output.HOagree(N).areaROC = aROC;
            output.HOagree(N).faRate = falseAlarmRate;
            output.HOagree(N).detRate = detectionRate;

            clear checkFix paper* nfixs fixXY Y I J
        end % of goodTrials
        output.HOagree_stats = [mean([output.HOagree.areaROC]) std([output.HOagree.areaROC]) length([output.HOagree.areaROC])]; %'Mean' 'Stdev' 'Nsubs'
    else
        output.HOagree = [];
        output.HOagree_stats = [NaN NaN Nsubs] %'Mean' 'Stdev' 'Nsubs'
    end

    clear badNaN accuracy current goodones XSubConsistency goodTrials fileName
    clear paper* nfixs fixXY Y I J badNaN accuracy current fix*reg frac*
else
    output.HOagree = [];
    output.HOagree_stats = [NaN NaN Nsubs] %'Mean' 'Stdev' 'Nsubs'
    clear badNaN accuracy current goodones XSubConsistency goodTrials fileName
    clear paper* nfixs fixXY Y I J badNaN accuracy current fix*reg frac*
end
