function [mu, cY, k] = fitPowerExponential (y, sn)
%function [mu, Sigma, k] = fitPowerExponential (y, sn)
% y  = data
% sn = subsampling of the data for speed
%
% Fits a multivariate power exponential to the data y
% 
% 
% y = [Nsamples x dimensions]
%
% Lindsey 1999


mu = mean(y,1);
cY = cov(y);

if nargin == 2
    y=y(1:sn:end,:);
end
R = size(y,2);
Nsamples = size(y,1);

y = y - repmat(mu, Nsamples, 1);
icY=inv(cY);

kTest = logspace(-4, 0, 50);
for j = 1:length(kTest)
    drawnow
    
    k = kTest(j);
        
    % All the computations are done using logarithms to avoid INF and NaN
    %Kc = 2^(1/k) * gamma((R+2)/(2*k)) / (R * gamma(R/(2*k)));
    lnKc = log(2)/k +  gammaln((R+2)/(2*k)) - log(R) - gammaln(R/(2*k));
    
    %S = exp(lnKc) * icY;
    S = icY;
    
    %Kj = R * gamma(R/2) / (pi^(R/2)) * sqrt(det(S)) / gamma(1+R/(2*k)) / 2^(1+R/(2*k));
    lnKj = log(R) + gammaln(R/2) - log(pi)*R/2 + lnKc*R/2 + log(sqrt(det(icY))) - gammaln(1+R/(2*k)) - log(2)*(1+R/(2*k));

    if R==1
        d = y.*S.*y;
    else
        xmX=y*S; 
        d=dot(xmX',y');
    end
    Likelihood(j) = Nsamples*(lnKj) -.5*sum(d.^k)*exp(lnKc*k);
end

% Likelihood
Likelihood = real(Likelihood);
n = find(isnan(Likelihood)); 
Likelihood(n) = min(Likelihood);
n = find(isinf(Likelihood)); 
Likelihood(n) = min(Likelihood);

[foo, m] = max(Likelihood);
k = kTest(m);

% lnKc = log(2)/k +  gammaln((R+2)/(2*k)) - log(R) - gammaln(R/(2*k));
% Sigma = cY / exp(lnKc);

% figure
% plot(kTest, Likelihood,'o-')
