function [output] = showContextOracleMap(imgName,thresh,dispMap)
%% PURPOSE: Show the (Empirical) CONTEXT ORACLE map for an image
% ==>  Input Arguments: 
%      imgName (example- 'U0121_1RTE.jpg') ... default: 'testImg.jpg'
%      thresh  (example- [0.1 0.2 0.3]) ... default: [0.05 0.25] which is 5% & 25% of img
%      dispMap  (0 [No] or 1 [Yes]) ... default: 1 

%% SET UP:
%Folders:
warning off
HOME = pwd;
init(HOME)

%Load Image:
if ~exist('imgName','var'); 
    load stimList
    stimList = stimList_ALL(randperm(length(stimList_ALL)))';
    imgName = [stimList{1} '.jpg'];
end
imgPath = which(imgName);
if isempty(imgPath);
    disp(['ERROR:  ' imgName '  was not found ']); return;
else
    img = imread([imgName]);
end;

%Set Thresholds:
if ~exist('thresh','var'); thresh = [0.05 0.25]; end

%Initialize stuff:
stimSize = size(img);  stimSize = stimSize(1:2);  %stimulus dimensions
Tsal_px = thresh * (stimSize(1)*stimSize(2));
exponentSAL = 0.025;                % modulates: SALIENCY MAP
exponentINRIA = 0.025;              % modulates: OBJECT MAP (INRIA)
whiteMat = zeros(stimSize);         %blank matrix

%Figure stuff:
scnsize = get(0,'ScreenSize');
fullscn=[5 40  scnsize(3)-10 scnsize(4)-120];

%Display stuff
if ~exist('dispMap','var'); dispMap = 1; end

%% ========================================================= %%
%% Load mean context oracle map
imgPath = which([imgName(1:end-4) '_contextOracleMap.mat']);
if isempty(imgPath);
    disp(['ERROR:  ' imgName '  was not found in the folder /Dataset_ContextOracle']); return;
else
    load(imgPath);
end;

%% ========================================================= %%
%% DISPLAY:
if dispMap
    map = contextOracleMap;
    figure('Position',fullscn,'Name',['Context Oracle Map for: ' imgName]);
    subplot(2,2,1:2);
    imagesc(img); title([ 'Original Stimulus: ' imgName]); axis off equal; hold on;
    for t = 1:2
        [imgFixRegions_thresh{t}] = findPredRegion(map,Tsal_px(t),0);
        subplot(2,2,t+2)
        imagesc(imgFixRegions_thresh{t}.*double(img(:,:,1))); 
        title(['Empirically Defined Context Region: Thresh ' num2str(thresh(t)*100) '%']); colormap(gray); axis off equal; hold on;
    end
end
output.contextOracleMap = contextOracleMap;
% for t = 1:length(Tsal_px)
%     [imgFixRegions_thresh{t}] = findPredRegion(contextOracleMap,Tsal_px(t),0);
%     eval(['output.contextOracleMap_' num2str(thresh(t)*100) 'per_Thresh = imgFixRegions_thresh{t} ;'])
% end
